@@ -54,15 +54,26 @@ class QuickbooksCore(SitesCore):
                 if self.does_element_displayed('//input[@id="ius-password"]'):
                     self.browser.input_text('//input[@id="ius-password"]', self.password)
                     self.browser.click_element_when_visible('//button[@id="ius-sign-in-submit-btn"]')
+                elif self.does_element_displayed('//input[@id="iux-password-confirmation-password"]'):
+                    self.browser.input_text('//input[@id="iux-password-confirmation-password"]', self.password)
+                    self.browser.click_element_when_visible(
+                        '//button[@data-testid="passwordVerificationContinueButton"]'
+                    )
                 else:
                     self.browser.click_element_when_visible('//button[@id="ius-identifier-first-submit-btn"]')
-                    self.wait_element('//input[@id="ius-sign-in-mfa-password-collection-current-password"]')
-                    self.browser.input_text(
-                        '//input[@id="ius-sign-in-mfa-password-collection-current-password"]', self.password
-                    )
-                    self.browser.click_element_when_visible(
-                        '//input[@id="ius-sign-in-mfa-password-collection-continue-btn"]'
-                    )
+                    if self.does_element_displayed('//input[@id="iux-password-confirmation-password"]'):
+                        self.browser.input_text('//input[@id="iux-password-confirmation-password"]', self.password)
+                        self.browser.click_element_when_visible(
+                            '//button[@data-testid="passwordVerificationContinueButton"]'
+                        )
+                    else:
+                        self.wait_element('//input[@id="ius-sign-in-mfa-password-collection-current-password"]')
+                        self.browser.input_text(
+                            '//input[@id="ius-sign-in-mfa-password-collection-current-password"]', self.password
+                        )
+                        self.browser.click_element_when_visible(
+                            '//input[@id="ius-sign-in-mfa-password-collection-continue-btn"]'
+                        )
 
                 self.wait_element("//div[text()=\"Let's make sure you're you\"]", timeout=10, is_need_screenshot=False)
                 if self.does_element_displayed("//div[text()=\"Let's make sure you're you\"]"):
@@ -73,6 +84,10 @@ class QuickbooksCore(SitesCore):
                     self.wait_element('//input[@id="ius-mfa-confirm-code"]')
                     self.browser.input_text('//input[@id="ius-mfa-confirm-code"]', self.get_otp_code())
                     self.browser.click_element_when_visible('//input[@id="ius-mfa-otp-submit-btn"]')
+
+                if self.browser.does_page_contain_element('//button[@id="ius-verified-user-update-btn-skip"]'):
+                    self.browser.click_element_when_visible('//button[@id="ius-verified-user-update-btn-skip"]')
+
                 self.wait_element('//*[@data-id="navigation-container"]')
                 if self.does_element_displayed('//*[@data-id="navigation-container"]'):
                     self.base_url = self.get_base_url(self.browser.get_location())
